
import 'dart:async';

import 'package:flutter/services.dart';

class InAppPurchasing {
  static const MethodChannel _channel = const MethodChannel('in_app_purchasing');

  void Function() _onConnected;
  void Function(String details) _onPaymentSuccess;
  void Function(String message) _onError;

  InAppPurchasing(){
    _channel.setMethodCallHandler((call)async{
      if(call.method == "OnConnected"){
        _onConnected?.call();
      }
      if(call.method == "onPaymentSuccess"){
        _onPaymentSuccess?.call(call.arguments as String);
      }
      if(call.method == "OnError"){
        _onError?.call(call.arguments as String);
      }
    });
  }

  void addListener(void Function() onConnected, void Function(String details) onPaymentSuccess, void Function(String message) onError){
    _onConnected = onConnected;
    _onPaymentSuccess = onPaymentSuccess;
    _onError = onError;
  }

  ///Client connection
  Future<bool> isClientConnected() async {
    return _channel.invokeMethod<bool>('isClientConnected').then((value){
      return value;
    }).catchError((e){
      return false;
    });
  }
  Future<bool> connectClient()async{
      return _channel.invokeMethod<bool>('connectBillingClient').then((value){
        return value;
      }).catchError((e){
        return false;
      });
  }
  Future<bool> makePurchase(String pId) async{
    return _channel.invokeMethod<bool>('makePurchase', pId).then((value){
      return value;
    }).catchError((e){
      return false;
    });
  }
  Future<bool> disconnectClient() async{
    return _channel.invokeMethod<bool>('disconnectBillingClient').then((value){
      return value;
    }).catchError((e){
      return false;
    });
  }
}
